@@ -39,6 +39,7 @@ import qualified Data.ListLike       as LL
 import           Data.ListLike       (ListLike)
 import           Lens.Micro.Platform (over, Lens', _2, (.~), (&))
 import           Data.Binary         (Binary)
+import           Data.Semigroup      (Semigroup)
 
 -- | A CompletionTree is a map of partial completions.
 --
@@ -60,7 +61,7 @@ import           Data.Binary         (Binary)
 -- (The empty strings are needed to denote the end of a word)
 -- (A CompletionTree is not limited to a binary tree)
 newtype CompletionTree a = CompletionTree {_unCompletionTree :: (Map a (CompletionTree a))}
-  deriving (Monoid, Eq, Binary)
+  deriving (Semigroup, Monoid, Eq, Binary)
 
 unCompletionTree :: Lens' (CompletionTree a) (Map a (CompletionTree a))
 unCompletionTree f ct = (\unCompletionTree' -> ct {_unCompletionTree = unCompletionTree'}) <$>
